Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
AES.GCMThe transformed message, packed with the authentication tag.
encrypt ~key ~iv ?adata msg is the result containing msg encrypted under key, with iv as the initialization vector, and the authentication tag computed over both adata and msg.