Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
S.CCMCounter with CBC-MAC mode.
Construct the encryption key corresponding to secret, that will produce authentication codes with the length maclen.
encrypt ~key ~nonce ?adata msg is msg encrypted under key and nonce, packed with authentication data computed over msg and adata.